"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetPromoCodesRequest(object):
    """Implementation of the 'GetPromoCodesRequest' model.

    Attributes:
        active_only (bool): If true, filters results to show only promocodes that are
            active. If **false**, all promocodes are returned.  Default: **true**
        online_only (bool): If `true`, filters results to show only promocodes that
            can be used for online sale.  If `false`, all promocodes are returned.
            Default: **false**
        start_date (datetime): Filters results to promocodes that were activated
            after this date.
        end_date (datetime): Filters results to promocodes that were activated before
            this date.
        last_modified_date (datetime): Filters results to promocodes that were
            modified on or after this date.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "active_only": "ActiveOnly",
        "online_only": "OnlineOnly",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "last_modified_date": "LastModifiedDate",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "active_only",
        "online_only",
        "start_date",
        "end_date",
        "last_modified_date",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        active_only=APIHelper.SKIP,
        online_only=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        last_modified_date=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetPromoCodesRequest instance."""
        # Initialize members of the class
        if active_only is not APIHelper.SKIP:
            self.active_only = active_only
        if online_only is not APIHelper.SKIP:
            self.online_only = online_only
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if last_modified_date is not APIHelper.SKIP:
            self.last_modified_date =\
                 APIHelper.apply_datetime_converter(
                last_modified_date, APIHelper.RFC3339DateTime)\
                 if last_modified_date else None
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        active_only =\
            dictionary.get("ActiveOnly")\
            if "ActiveOnly" in dictionary.keys()\
                else APIHelper.SKIP
        online_only =\
            dictionary.get("OnlineOnly")\
            if "OnlineOnly" in dictionary.keys()\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        last_modified_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDate")).datetime\
            if dictionary.get("LastModifiedDate") else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(active_only,
                   online_only,
                   start_date,
                   end_date,
                   last_modified_date,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _active_only=(
            self.active_only
            if hasattr(self, "active_only")
            else None
        )
        _online_only=(
            self.online_only
            if hasattr(self, "online_only")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active_only={_active_only!r}, "
            f"online_only={_online_only!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"last_modified_date={_last_modified_date!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _active_only=(
            self.active_only
            if hasattr(self, "active_only")
            else None
        )
        _online_only=(
            self.online_only
            if hasattr(self, "online_only")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active_only={_active_only!s}, "
            f"online_only={_online_only!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"last_modified_date={_last_modified_date!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class DaysValidEnum(object):
    """Implementation of the 'DaysValid' enum.

    Attributes:
        SUNDAY: The enum member of type str.
        MONDAY: The enum member of type str.
        TUESDAY: The enum member of type str.
        WEDNESDAY: The enum member of type str.
        THURSDAY: The enum member of type str.
        FRIDAY: The enum member of type str.
        SATURDAY: The enum member of type str.

    """

    SUNDAY = "Sunday"

    MONDAY = "Monday"

    TUESDAY = "Tuesday"

    WEDNESDAY = "Wednesday"

    THURSDAY = "Thursday"

    FRIDAY = "Friday"

    SATURDAY = "Saturday"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.assigned_client_index import (
    AssignedClientIndex,
)
from mindbodypublicapi.models.client_credit_card import (
    ClientCreditCard,
)
from mindbodypublicapi.models.client_relationship import (
    ClientRelationship,
)
from mindbodypublicapi.models.client_suspension_info import (
    ClientSuspensionInfo,
)
from mindbodypublicapi.models.custom_client_field_value import (
    CustomClientFieldValue,
)
from mindbodypublicapi.models.liability import (
    Liability,
)
from mindbodypublicapi.models.location import (
    Location,
)
from mindbodypublicapi.models.prospect_stage import (
    ProspectStage,
)
from mindbodypublicapi.models.sales_rep import (
    SalesRep,
)


class ClientWithSuspensionInfo(object):
    """Implementation of the 'ClientWithSuspensionInfo' model.

    A Client DTO with Suspension Informatoin

    Attributes:
        suspension_info (ClientSuspensionInfo): A Client DTO with Suspension
            Informatoin
        appointment_gender_preference (AppointmentGenderPreference1Enum): The gender
            of staff member with whom the client prefers to book appointments.
        birth_date (datetime): The client’s date of birth.
        country (str): The client’s country.
        creation_date (datetime): The date the client’s profile was created and added
            to the business, either by the client from the online store, or by a
            staff member. This value always returns in the format
            `yyyy-mm-ddThh:mm:ss:ms`.
        custom_client_fields (List[CustomClientFieldValue]): Contains information
            about the custom fields used for clients in the business.
        client_credit_card (ClientCreditCard): A client credit card.
        client_indexes (List[AssignedClientIndex]): Contains the IDs of the client’s
            assigned ClientIndexes and ClientIndexValues.    If an index is already
            assigned to the client, it is overwritten with the passed index value.
            You cannot currently remove client indexes using the Public API. Only the
            indexes passed in the request are returned in the response.
        client_relationships (List[ClientRelationship]): Contains information about
            the relationship between two clients.    This parameter does not include
            all of the relationships assigned to the client, only the ones passed in
            the request.
        first_appointment_date (datetime): The date of the client’s first booked
            appointment at the business.
        first_class_date (datetime): The date of the clients first booked class at
            the business.
        first_name (str): The client’s first name.
        id (str): The client’s ID, as configured by the business owner. This is the
            client’s barcode ID if the business owner assigns barcodes to clients.
            This ID is used throughout the Public API for client-related Public API
            calls. When used in a POST `UpdateClient` request, the `Id` is used to
            identify the client for the update.
        is_company (bool): When `true`, indicates that the client should be marked as
            a company at the business.<br />  When `false`, indicates the client is
            an individual and does not represent a company.
        is_prospect (bool): This value is set only if the business owner allows
            individuals to be prospects.<br />  When `true`, indicates that the
            client should be marked as a prospect for the business.<br />  When
            `false`, indicates that the client should not be marked as a prospect for
            the business.
        last_name (str): The client’s last name.
        liability (Liability): The model property of type Liability.
        liability_release (bool): Passing `true` sets the client’s liability
            information as follows:  * `IsReleased` is set to `true`.  *
            `AgreementDate` is set to the time zone of the business when the call was
            processed.  * `ReleasedBy` is set to `null` if the call is made by the
            client, `0` if the call was made by the business owner, or to a specific
            staff member’s ID if a staff member made the call.  Passing `false` sets
            the client’s liability information as follows:  * `IsReleased` is set to
            `false`.  * `AgreementDate` is set to `null`.  * `ReleasedBy` is set to
            `null`.
        membership_icon (int): The ID of the [membership
            icon](https://support.mindbodyonline.com/s/article/203259703-Membership-Se
            tup-screen?language=en_US) displayed next to the client’s name, if the
            client has a membership on their account.
        mobile_provider (int): The client’s mobile provider.
        notes (str): Any notes entered on the client’s account by staff members. This
            value should never be shown to clients unless the business owner has a
            specific reason for showing them.
        state (str): The client’s state.
        unique_id (int): The client’s system-generated ID at the business. This value
            cannot be changed by business owners and is always unique across all
            clients at the business. This ID is not widely used in the Public API,
            but can be used by your application to uniquely identify clients.
        last_modified_date_time (datetime): The UTC date and time when the client’s
            information was last modified.
        red_alert (str): Contains any red alert information entered by the business
            owner for the client.
        yellow_alert (str): Contains any yellow alert information entered by the
            business owner for the client.
        middle_name (str): The client’s middle name.
        prospect_stage (ProspectStage): The model property of type ProspectStage.
        email (str): The client’s email address.
        mobile_phone (str): The client’s mobile phone number.
        home_phone (str): The client’s home phone number.
        work_phone (str): The client’s work phone number.
        account_balance (float): The client’s current [account
            balance](https://mindbody-online-support.force.com/support/s/article/20326
            2013-Adding-account-payments-video-tutorial?language=en_US).
        address_line_1 (str): The first line of the client’s street address.
        address_line_2 (str): The second line of the client’s street address, if
            needed.
        city (str): The client’s city.
        postal_code (str): The client’s postal code.
        work_extension (str): The client’s work phone extension number.
        referred_by (str): Specifies how the client was referred to the business. You
            can get a list of possible strings using the `GetClientReferralTypes`
            endpoint.
        photo_url (str): The URL of the client’s photo for the client profile.
        emergency_contact_info_name (str): The name of the client’s emergency contact.
        emergency_contact_info_email (str): The email address of the client’s
            emergency contact.
        emergency_contact_info_phone (str): The phone number of the client’s
            emergency contact.
        emergency_contact_info_relationship (str): The client’s relationship with the
            emergency contact.
        gender (str): The gender of the client.
        last_formula_notes (str): The last [formula
            note](https://support.mindbodyonline.com/s/article/203259903-Appointments-
            Formula-notes?language=en_US) entered for the client.
        active (bool): When `true`, indicates that the client’s profile is marked as
            active on the site.<br />  When `false`, the client’s profile is
            inactive.  Defaults to `true` based on the assumption that if a client is
            currently inactive OR is to be marked inactive, this property will
            explicitly be mapped/set to `false`.
        sales_reps (List[SalesRep]): A list of sales representatives.
        status (str): The status of the client in the business. Possible values are:
            * Declined  * Non-Member  * Active  * Expired  * Suspended  * Terminated
        action (Action1Enum): The action taken.
        send_account_emails (bool): When `true`, indicates that the client has opted
            to receive general account notifications by email. This property is
            editable.   <br />Default: **false**
        send_account_texts (bool): When `true`, indicates that the client has opted
            to receive general account notifications by text message. This parameter
            cannot be updated by developers. If included in a request, it is ignored.
        send_promotional_emails (bool): When `true`, indicates that the client has
            opted to receive promotional notifications by email. This property is
            editable.   <br />Default: **false**
        send_promotional_texts (bool): When `true`, indicates that the client has
            opted to receive promotional notifications by text message. This
            parameter cannot be updated by developers. If included in a request, it
            is ignored.
        send_schedule_emails (bool): When `true`, indicates that the client has opted
            to receive schedule notifications by email. This property is editable.
            <br />Default: **false**
        send_schedule_texts (bool): When `true`, indicates that the client has opted
            to receive schedule notifications by text message. This parameter cannot
            be updated by developers. If included in a request, it is ignored.
        home_location (Location): The model property of type Location.
        locker_number (str): The clients locker number.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "suspension_info": "SuspensionInfo",
        "appointment_gender_preference": "AppointmentGenderPreference",
        "birth_date": "BirthDate",
        "country": "Country",
        "creation_date": "CreationDate",
        "custom_client_fields": "CustomClientFields",
        "client_credit_card": "ClientCreditCard",
        "client_indexes": "ClientIndexes",
        "client_relationships": "ClientRelationships",
        "first_appointment_date": "FirstAppointmentDate",
        "first_class_date": "FirstClassDate",
        "first_name": "FirstName",
        "id": "Id",
        "is_company": "IsCompany",
        "is_prospect": "IsProspect",
        "last_name": "LastName",
        "liability": "Liability",
        "liability_release": "LiabilityRelease",
        "membership_icon": "MembershipIcon",
        "mobile_provider": "MobileProvider",
        "notes": "Notes",
        "state": "State",
        "unique_id": "UniqueId",
        "last_modified_date_time": "LastModifiedDateTime",
        "red_alert": "RedAlert",
        "yellow_alert": "YellowAlert",
        "middle_name": "MiddleName",
        "prospect_stage": "ProspectStage",
        "email": "Email",
        "mobile_phone": "MobilePhone",
        "home_phone": "HomePhone",
        "work_phone": "WorkPhone",
        "account_balance": "AccountBalance",
        "address_line_1": "AddressLine1",
        "address_line_2": "AddressLine2",
        "city": "City",
        "postal_code": "PostalCode",
        "work_extension": "WorkExtension",
        "referred_by": "ReferredBy",
        "photo_url": "PhotoUrl",
        "emergency_contact_info_name": "EmergencyContactInfoName",
        "emergency_contact_info_email": "EmergencyContactInfoEmail",
        "emergency_contact_info_phone": "EmergencyContactInfoPhone",
        "emergency_contact_info_relationship": "EmergencyContactInfoRelationship",
        "gender": "Gender",
        "last_formula_notes": "LastFormulaNotes",
        "active": "Active",
        "sales_reps": "SalesReps",
        "status": "Status",
        "action": "Action",
        "send_account_emails": "SendAccountEmails",
        "send_account_texts": "SendAccountTexts",
        "send_promotional_emails": "SendPromotionalEmails",
        "send_promotional_texts": "SendPromotionalTexts",
        "send_schedule_emails": "SendScheduleEmails",
        "send_schedule_texts": "SendScheduleTexts",
        "home_location": "HomeLocation",
        "locker_number": "LockerNumber",
    }

    _optionals = [
        "suspension_info",
        "appointment_gender_preference",
        "birth_date",
        "country",
        "creation_date",
        "custom_client_fields",
        "client_credit_card",
        "client_indexes",
        "client_relationships",
        "first_appointment_date",
        "first_class_date",
        "first_name",
        "id",
        "is_company",
        "is_prospect",
        "last_name",
        "liability",
        "liability_release",
        "membership_icon",
        "mobile_provider",
        "notes",
        "state",
        "unique_id",
        "last_modified_date_time",
        "red_alert",
        "yellow_alert",
        "middle_name",
        "prospect_stage",
        "email",
        "mobile_phone",
        "home_phone",
        "work_phone",
        "account_balance",
        "address_line_1",
        "address_line_2",
        "city",
        "postal_code",
        "work_extension",
        "referred_by",
        "photo_url",
        "emergency_contact_info_name",
        "emergency_contact_info_email",
        "emergency_contact_info_phone",
        "emergency_contact_info_relationship",
        "gender",
        "last_formula_notes",
        "active",
        "sales_reps",
        "status",
        "action",
        "send_account_emails",
        "send_account_texts",
        "send_promotional_emails",
        "send_promotional_texts",
        "send_schedule_emails",
        "send_schedule_texts",
        "home_location",
        "locker_number",
    ]

    def __init__(
        self,
        suspension_info=APIHelper.SKIP,
        appointment_gender_preference=APIHelper.SKIP,
        birth_date=APIHelper.SKIP,
        country=APIHelper.SKIP,
        creation_date=APIHelper.SKIP,
        custom_client_fields=APIHelper.SKIP,
        client_credit_card=APIHelper.SKIP,
        client_indexes=APIHelper.SKIP,
        client_relationships=APIHelper.SKIP,
        first_appointment_date=APIHelper.SKIP,
        first_class_date=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        id=APIHelper.SKIP,
        is_company=APIHelper.SKIP,
        is_prospect=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        liability=APIHelper.SKIP,
        liability_release=APIHelper.SKIP,
        membership_icon=APIHelper.SKIP,
        mobile_provider=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        state=APIHelper.SKIP,
        unique_id=APIHelper.SKIP,
        last_modified_date_time=APIHelper.SKIP,
        red_alert=APIHelper.SKIP,
        yellow_alert=APIHelper.SKIP,
        middle_name=APIHelper.SKIP,
        prospect_stage=APIHelper.SKIP,
        email=APIHelper.SKIP,
        mobile_phone=APIHelper.SKIP,
        home_phone=APIHelper.SKIP,
        work_phone=APIHelper.SKIP,
        account_balance=APIHelper.SKIP,
        address_line_1=APIHelper.SKIP,
        address_line_2=APIHelper.SKIP,
        city=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        work_extension=APIHelper.SKIP,
        referred_by=APIHelper.SKIP,
        photo_url=APIHelper.SKIP,
        emergency_contact_info_name=APIHelper.SKIP,
        emergency_contact_info_email=APIHelper.SKIP,
        emergency_contact_info_phone=APIHelper.SKIP,
        emergency_contact_info_relationship=APIHelper.SKIP,
        gender=APIHelper.SKIP,
        last_formula_notes=APIHelper.SKIP,
        active=APIHelper.SKIP,
        sales_reps=APIHelper.SKIP,
        status=APIHelper.SKIP,
        action=APIHelper.SKIP,
        send_account_emails=APIHelper.SKIP,
        send_account_texts=APIHelper.SKIP,
        send_promotional_emails=APIHelper.SKIP,
        send_promotional_texts=APIHelper.SKIP,
        send_schedule_emails=APIHelper.SKIP,
        send_schedule_texts=APIHelper.SKIP,
        home_location=APIHelper.SKIP,
        locker_number=APIHelper.SKIP):
        """Initialize a ClientWithSuspensionInfo instance."""
        # Initialize members of the class
        if suspension_info is not APIHelper.SKIP:
            self.suspension_info = suspension_info
        if appointment_gender_preference is not APIHelper.SKIP:
            self.appointment_gender_preference = appointment_gender_preference
        if birth_date is not APIHelper.SKIP:
            self.birth_date =\
                 APIHelper.apply_datetime_converter(
                birth_date, APIHelper.RFC3339DateTime)\
                 if birth_date else None
        if country is not APIHelper.SKIP:
            self.country = country
        if creation_date is not APIHelper.SKIP:
            self.creation_date =\
                 APIHelper.apply_datetime_converter(
                creation_date, APIHelper.RFC3339DateTime)\
                 if creation_date else None
        if custom_client_fields is not APIHelper.SKIP:
            self.custom_client_fields = custom_client_fields
        if client_credit_card is not APIHelper.SKIP:
            self.client_credit_card = client_credit_card
        if client_indexes is not APIHelper.SKIP:
            self.client_indexes = client_indexes
        if client_relationships is not APIHelper.SKIP:
            self.client_relationships = client_relationships
        if first_appointment_date is not APIHelper.SKIP:
            self.first_appointment_date =\
                 APIHelper.apply_datetime_converter(
                first_appointment_date, APIHelper.RFC3339DateTime)\
                 if first_appointment_date else None
        if first_class_date is not APIHelper.SKIP:
            self.first_class_date =\
                 APIHelper.apply_datetime_converter(
                first_class_date, APIHelper.RFC3339DateTime)\
                 if first_class_date else None
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if id is not APIHelper.SKIP:
            self.id = id
        if is_company is not APIHelper.SKIP:
            self.is_company = is_company
        if is_prospect is not APIHelper.SKIP:
            self.is_prospect = is_prospect
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if liability is not APIHelper.SKIP:
            self.liability = liability
        if liability_release is not APIHelper.SKIP:
            self.liability_release = liability_release
        if membership_icon is not APIHelper.SKIP:
            self.membership_icon = membership_icon
        if mobile_provider is not APIHelper.SKIP:
            self.mobile_provider = mobile_provider
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if state is not APIHelper.SKIP:
            self.state = state
        if unique_id is not APIHelper.SKIP:
            self.unique_id = unique_id
        if last_modified_date_time is not APIHelper.SKIP:
            self.last_modified_date_time =\
                 APIHelper.apply_datetime_converter(
                last_modified_date_time, APIHelper.RFC3339DateTime)\
                 if last_modified_date_time else None
        if red_alert is not APIHelper.SKIP:
            self.red_alert = red_alert
        if yellow_alert is not APIHelper.SKIP:
            self.yellow_alert = yellow_alert
        if middle_name is not APIHelper.SKIP:
            self.middle_name = middle_name
        if prospect_stage is not APIHelper.SKIP:
            self.prospect_stage = prospect_stage
        if email is not APIHelper.SKIP:
            self.email = email
        if mobile_phone is not APIHelper.SKIP:
            self.mobile_phone = mobile_phone
        if home_phone is not APIHelper.SKIP:
            self.home_phone = home_phone
        if work_phone is not APIHelper.SKIP:
            self.work_phone = work_phone
        if account_balance is not APIHelper.SKIP:
            self.account_balance = account_balance
        if address_line_1 is not APIHelper.SKIP:
            self.address_line_1 = address_line_1
        if address_line_2 is not APIHelper.SKIP:
            self.address_line_2 = address_line_2
        if city is not APIHelper.SKIP:
            self.city = city
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if work_extension is not APIHelper.SKIP:
            self.work_extension = work_extension
        if referred_by is not APIHelper.SKIP:
            self.referred_by = referred_by
        if photo_url is not APIHelper.SKIP:
            self.photo_url = photo_url
        if emergency_contact_info_name is not APIHelper.SKIP:
            self.emergency_contact_info_name = emergency_contact_info_name
        if emergency_contact_info_email is not APIHelper.SKIP:
            self.emergency_contact_info_email = emergency_contact_info_email
        if emergency_contact_info_phone is not APIHelper.SKIP:
            self.emergency_contact_info_phone = emergency_contact_info_phone
        if emergency_contact_info_relationship is not APIHelper.SKIP:
            self.emergency_contact_info_relationship =\
                 emergency_contact_info_relationship
        if gender is not APIHelper.SKIP:
            self.gender = gender
        if last_formula_notes is not APIHelper.SKIP:
            self.last_formula_notes = last_formula_notes
        if active is not APIHelper.SKIP:
            self.active = active
        if sales_reps is not APIHelper.SKIP:
            self.sales_reps = sales_reps
        if status is not APIHelper.SKIP:
            self.status = status
        if action is not APIHelper.SKIP:
            self.action = action
        if send_account_emails is not APIHelper.SKIP:
            self.send_account_emails = send_account_emails
        if send_account_texts is not APIHelper.SKIP:
            self.send_account_texts = send_account_texts
        if send_promotional_emails is not APIHelper.SKIP:
            self.send_promotional_emails = send_promotional_emails
        if send_promotional_texts is not APIHelper.SKIP:
            self.send_promotional_texts = send_promotional_texts
        if send_schedule_emails is not APIHelper.SKIP:
            self.send_schedule_emails = send_schedule_emails
        if send_schedule_texts is not APIHelper.SKIP:
            self.send_schedule_texts = send_schedule_texts
        if home_location is not APIHelper.SKIP:
            self.home_location = home_location
        if locker_number is not APIHelper.SKIP:
            self.locker_number = locker_number

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        suspension_info =\
            ClientSuspensionInfo.from_dictionary(
                dictionary.get("SuspensionInfo"))\
                if "SuspensionInfo" in dictionary.keys()\
                else APIHelper.SKIP
        appointment_gender_preference =\
            dictionary.get("AppointmentGenderPreference")\
            if dictionary.get("AppointmentGenderPreference")\
                else APIHelper.SKIP
        birth_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("BirthDate")).datetime\
            if dictionary.get("BirthDate") else APIHelper.SKIP
        country =\
            dictionary.get("Country")\
            if dictionary.get("Country")\
                else APIHelper.SKIP
        creation_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("CreationDate")).datetime\
            if dictionary.get("CreationDate") else APIHelper.SKIP
        custom_client_fields = None
        if dictionary.get("CustomClientFields") is not None:
            custom_client_fields = [
                CustomClientFieldValue.from_dictionary(x)
                    for x in dictionary.get("CustomClientFields")
            ]
        else:
            custom_client_fields = APIHelper.SKIP
        client_credit_card =\
            ClientCreditCard.from_dictionary(
                dictionary.get("ClientCreditCard"))\
                if "ClientCreditCard" in dictionary.keys()\
                else APIHelper.SKIP
        client_indexes = None
        if dictionary.get("ClientIndexes") is not None:
            client_indexes = [
                AssignedClientIndex.from_dictionary(x)
                    for x in dictionary.get("ClientIndexes")
            ]
        else:
            client_indexes = APIHelper.SKIP
        client_relationships = None
        if dictionary.get("ClientRelationships") is not None:
            client_relationships = [
                ClientRelationship.from_dictionary(x)
                    for x in dictionary.get("ClientRelationships")
            ]
        else:
            client_relationships = APIHelper.SKIP
        first_appointment_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("FirstAppointmentDate")).datetime\
            if dictionary.get("FirstAppointmentDate") else APIHelper.SKIP
        first_class_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("FirstClassDate")).datetime\
            if dictionary.get("FirstClassDate") else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        is_company =\
            dictionary.get("IsCompany")\
            if "IsCompany" in dictionary.keys()\
                else APIHelper.SKIP
        is_prospect =\
            dictionary.get("IsProspect")\
            if "IsProspect" in dictionary.keys()\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        liability =\
            Liability.from_dictionary(
                dictionary.get("Liability"))\
                if "Liability" in dictionary.keys()\
                else APIHelper.SKIP
        liability_release =\
            dictionary.get("LiabilityRelease")\
            if "LiabilityRelease" in dictionary.keys()\
                else APIHelper.SKIP
        membership_icon =\
            dictionary.get("MembershipIcon")\
            if dictionary.get("MembershipIcon")\
                else APIHelper.SKIP
        mobile_provider =\
            dictionary.get("MobileProvider")\
            if dictionary.get("MobileProvider")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        state =\
            dictionary.get("State")\
            if dictionary.get("State")\
                else APIHelper.SKIP
        unique_id =\
            dictionary.get("UniqueId")\
            if dictionary.get("UniqueId")\
                else APIHelper.SKIP
        last_modified_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDateTime")).datetime\
            if dictionary.get("LastModifiedDateTime") else APIHelper.SKIP
        red_alert =\
            dictionary.get("RedAlert")\
            if dictionary.get("RedAlert")\
                else APIHelper.SKIP
        yellow_alert =\
            dictionary.get("YellowAlert")\
            if dictionary.get("YellowAlert")\
                else APIHelper.SKIP
        middle_name =\
            dictionary.get("MiddleName")\
            if dictionary.get("MiddleName")\
                else APIHelper.SKIP
        prospect_stage =\
            ProspectStage.from_dictionary(
                dictionary.get("ProspectStage"))\
                if "ProspectStage" in dictionary.keys()\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        mobile_phone =\
            dictionary.get("MobilePhone")\
            if dictionary.get("MobilePhone")\
                else APIHelper.SKIP
        home_phone =\
            dictionary.get("HomePhone")\
            if dictionary.get("HomePhone")\
                else APIHelper.SKIP
        work_phone =\
            dictionary.get("WorkPhone")\
            if dictionary.get("WorkPhone")\
                else APIHelper.SKIP
        account_balance =\
            dictionary.get("AccountBalance")\
            if dictionary.get("AccountBalance")\
                else APIHelper.SKIP
        address_line_1 =\
            dictionary.get("AddressLine1")\
            if dictionary.get("AddressLine1")\
                else APIHelper.SKIP
        address_line_2 =\
            dictionary.get("AddressLine2")\
            if dictionary.get("AddressLine2")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        work_extension =\
            dictionary.get("WorkExtension")\
            if dictionary.get("WorkExtension")\
                else APIHelper.SKIP
        referred_by =\
            dictionary.get("ReferredBy")\
            if dictionary.get("ReferredBy")\
                else APIHelper.SKIP
        photo_url =\
            dictionary.get("PhotoUrl")\
            if dictionary.get("PhotoUrl")\
                else APIHelper.SKIP
        emergency_contact_info_name =\
            dictionary.get("EmergencyContactInfoName")\
            if dictionary.get("EmergencyContactInfoName")\
                else APIHelper.SKIP
        emergency_contact_info_email =\
            dictionary.get("EmergencyContactInfoEmail")\
            if dictionary.get("EmergencyContactInfoEmail")\
                else APIHelper.SKIP
        emergency_contact_info_phone =\
            dictionary.get("EmergencyContactInfoPhone")\
            if dictionary.get("EmergencyContactInfoPhone")\
                else APIHelper.SKIP
        emergency_contact_info_relationship =\
            dictionary.get("EmergencyContactInfoRelationship")\
            if dictionary.get("EmergencyContactInfoRelationship")\
                else APIHelper.SKIP
        gender =\
            dictionary.get("Gender")\
            if dictionary.get("Gender")\
                else APIHelper.SKIP
        last_formula_notes =\
            dictionary.get("LastFormulaNotes")\
            if dictionary.get("LastFormulaNotes")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        sales_reps = None
        if dictionary.get("SalesReps") is not None:
            sales_reps = [
                SalesRep.from_dictionary(x)
                    for x in dictionary.get("SalesReps")
            ]
        else:
            sales_reps = APIHelper.SKIP
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        send_account_emails =\
            dictionary.get("SendAccountEmails")\
            if "SendAccountEmails" in dictionary.keys()\
                else APIHelper.SKIP
        send_account_texts =\
            dictionary.get("SendAccountTexts")\
            if "SendAccountTexts" in dictionary.keys()\
                else APIHelper.SKIP
        send_promotional_emails =\
            dictionary.get("SendPromotionalEmails")\
            if "SendPromotionalEmails" in dictionary.keys()\
                else APIHelper.SKIP
        send_promotional_texts =\
            dictionary.get("SendPromotionalTexts")\
            if "SendPromotionalTexts" in dictionary.keys()\
                else APIHelper.SKIP
        send_schedule_emails =\
            dictionary.get("SendScheduleEmails")\
            if "SendScheduleEmails" in dictionary.keys()\
                else APIHelper.SKIP
        send_schedule_texts =\
            dictionary.get("SendScheduleTexts")\
            if "SendScheduleTexts" in dictionary.keys()\
                else APIHelper.SKIP
        home_location =\
            Location.from_dictionary(
                dictionary.get("HomeLocation"))\
                if "HomeLocation" in dictionary.keys()\
                else APIHelper.SKIP
        locker_number =\
            dictionary.get("LockerNumber")\
            if dictionary.get("LockerNumber")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(suspension_info,
                   appointment_gender_preference,
                   birth_date,
                   country,
                   creation_date,
                   custom_client_fields,
                   client_credit_card,
                   client_indexes,
                   client_relationships,
                   first_appointment_date,
                   first_class_date,
                   first_name,
                   id,
                   is_company,
                   is_prospect,
                   last_name,
                   liability,
                   liability_release,
                   membership_icon,
                   mobile_provider,
                   notes,
                   state,
                   unique_id,
                   last_modified_date_time,
                   red_alert,
                   yellow_alert,
                   middle_name,
                   prospect_stage,
                   email,
                   mobile_phone,
                   home_phone,
                   work_phone,
                   account_balance,
                   address_line_1,
                   address_line_2,
                   city,
                   postal_code,
                   work_extension,
                   referred_by,
                   photo_url,
                   emergency_contact_info_name,
                   emergency_contact_info_email,
                   emergency_contact_info_phone,
                   emergency_contact_info_relationship,
                   gender,
                   last_formula_notes,
                   active,
                   sales_reps,
                   status,
                   action,
                   send_account_emails,
                   send_account_texts,
                   send_promotional_emails,
                   send_promotional_texts,
                   send_schedule_emails,
                   send_schedule_texts,
                   home_location,
                   locker_number)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _suspension_info=(
            self.suspension_info
            if hasattr(self, "suspension_info")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _birth_date=(
            self.birth_date
            if hasattr(self, "birth_date")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _creation_date=(
            self.creation_date
            if hasattr(self, "creation_date")
            else None
        )
        _custom_client_fields=(
            self.custom_client_fields
            if hasattr(self, "custom_client_fields")
            else None
        )
        _client_credit_card=(
            self.client_credit_card
            if hasattr(self, "client_credit_card")
            else None
        )
        _client_indexes=(
            self.client_indexes
            if hasattr(self, "client_indexes")
            else None
        )
        _client_relationships=(
            self.client_relationships
            if hasattr(self, "client_relationships")
            else None
        )
        _first_appointment_date=(
            self.first_appointment_date
            if hasattr(self, "first_appointment_date")
            else None
        )
        _first_class_date=(
            self.first_class_date
            if hasattr(self, "first_class_date")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_company=(
            self.is_company
            if hasattr(self, "is_company")
            else None
        )
        _is_prospect=(
            self.is_prospect
            if hasattr(self, "is_prospect")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _liability=(
            self.liability
            if hasattr(self, "liability")
            else None
        )
        _liability_release=(
            self.liability_release
            if hasattr(self, "liability_release")
            else None
        )
        _membership_icon=(
            self.membership_icon
            if hasattr(self, "membership_icon")
            else None
        )
        _mobile_provider=(
            self.mobile_provider
            if hasattr(self, "mobile_provider")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _red_alert=(
            self.red_alert
            if hasattr(self, "red_alert")
            else None
        )
        _yellow_alert=(
            self.yellow_alert
            if hasattr(self, "yellow_alert")
            else None
        )
        _middle_name=(
            self.middle_name
            if hasattr(self, "middle_name")
            else None
        )
        _prospect_stage=(
            self.prospect_stage
            if hasattr(self, "prospect_stage")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _account_balance=(
            self.account_balance
            if hasattr(self, "account_balance")
            else None
        )
        _address_line_1=(
            self.address_line_1
            if hasattr(self, "address_line_1")
            else None
        )
        _address_line_2=(
            self.address_line_2
            if hasattr(self, "address_line_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _work_extension=(
            self.work_extension
            if hasattr(self, "work_extension")
            else None
        )
        _referred_by=(
            self.referred_by
            if hasattr(self, "referred_by")
            else None
        )
        _photo_url=(
            self.photo_url
            if hasattr(self, "photo_url")
            else None
        )
        _emergency_contact_info_name=(
            self.emergency_contact_info_name
            if hasattr(self, "emergency_contact_info_name")
            else None
        )
        _emergency_contact_info_email=(
            self.emergency_contact_info_email
            if hasattr(self, "emergency_contact_info_email")
            else None
        )
        _emergency_contact_info_phone=(
            self.emergency_contact_info_phone
            if hasattr(self, "emergency_contact_info_phone")
            else None
        )
        _emergency_contact_info_relationship=(
            self.emergency_contact_info_relationship
            if hasattr(self, "emergency_contact_info_relationship")
            else None
        )
        _gender=(
            self.gender
            if hasattr(self, "gender")
            else None
        )
        _last_formula_notes=(
            self.last_formula_notes
            if hasattr(self, "last_formula_notes")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _sales_reps=(
            self.sales_reps
            if hasattr(self, "sales_reps")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _send_account_emails=(
            self.send_account_emails
            if hasattr(self, "send_account_emails")
            else None
        )
        _send_account_texts=(
            self.send_account_texts
            if hasattr(self, "send_account_texts")
            else None
        )
        _send_promotional_emails=(
            self.send_promotional_emails
            if hasattr(self, "send_promotional_emails")
            else None
        )
        _send_promotional_texts=(
            self.send_promotional_texts
            if hasattr(self, "send_promotional_texts")
            else None
        )
        _send_schedule_emails=(
            self.send_schedule_emails
            if hasattr(self, "send_schedule_emails")
            else None
        )
        _send_schedule_texts=(
            self.send_schedule_texts
            if hasattr(self, "send_schedule_texts")
            else None
        )
        _home_location=(
            self.home_location
            if hasattr(self, "home_location")
            else None
        )
        _locker_number=(
            self.locker_number
            if hasattr(self, "locker_number")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"suspension_info={_suspension_info!r}, "
            f"appointment_gender_preference={_appointment_gender_preference!r}, "
            f"birth_date={_birth_date!r}, "
            f"country={_country!r}, "
            f"creation_date={_creation_date!r}, "
            f"custom_client_fields={_custom_client_fields!r}, "
            f"client_credit_card={_client_credit_card!r}, "
            f"client_indexes={_client_indexes!r}, "
            f"client_relationships={_client_relationships!r}, "
            f"first_appointment_date={_first_appointment_date!r}, "
            f"first_class_date={_first_class_date!r}, "
            f"first_name={_first_name!r}, "
            f"id={_id!r}, "
            f"is_company={_is_company!r}, "
            f"is_prospect={_is_prospect!r}, "
            f"last_name={_last_name!r}, "
            f"liability={_liability!r}, "
            f"liability_release={_liability_release!r}, "
            f"membership_icon={_membership_icon!r}, "
            f"mobile_provider={_mobile_provider!r}, "
            f"notes={_notes!r}, "
            f"state={_state!r}, "
            f"unique_id={_unique_id!r}, "
            f"last_modified_date_time={_last_modified_date_time!r}, "
            f"red_alert={_red_alert!r}, "
            f"yellow_alert={_yellow_alert!r}, "
            f"middle_name={_middle_name!r}, "
            f"prospect_stage={_prospect_stage!r}, "
            f"email={_email!r}, "
            f"mobile_phone={_mobile_phone!r}, "
            f"home_phone={_home_phone!r}, "
            f"work_phone={_work_phone!r}, "
            f"account_balance={_account_balance!r}, "
            f"address_line_1={_address_line_1!r}, "
            f"address_line_2={_address_line_2!r}, "
            f"city={_city!r}, "
            f"postal_code={_postal_code!r}, "
            f"work_extension={_work_extension!r}, "
            f"referred_by={_referred_by!r}, "
            f"photo_url={_photo_url!r}, "
            f"emergency_contact_info_name={_emergency_contact_info_name!r}, "
            f"emergency_contact_info_email={_emergency_contact_info_email!r}, "
            f"emergency_contact_info_phone={_emergency_contact_info_phone!r}, "
            f"emergency_contact_info_relationship={_emergency_contact_info_relationship!r}, "
            f"gender={_gender!r}, "
            f"last_formula_notes={_last_formula_notes!r}, "
            f"active={_active!r}, "
            f"sales_reps={_sales_reps!r}, "
            f"status={_status!r}, "
            f"action={_action!r}, "
            f"send_account_emails={_send_account_emails!r}, "
            f"send_account_texts={_send_account_texts!r}, "
            f"send_promotional_emails={_send_promotional_emails!r}, "
            f"send_promotional_texts={_send_promotional_texts!r}, "
            f"send_schedule_emails={_send_schedule_emails!r}, "
            f"send_schedule_texts={_send_schedule_texts!r}, "
            f"home_location={_home_location!r}, "
            f"locker_number={_locker_number!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _suspension_info=(
            self.suspension_info
            if hasattr(self, "suspension_info")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _birth_date=(
            self.birth_date
            if hasattr(self, "birth_date")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _creation_date=(
            self.creation_date
            if hasattr(self, "creation_date")
            else None
        )
        _custom_client_fields=(
            self.custom_client_fields
            if hasattr(self, "custom_client_fields")
            else None
        )
        _client_credit_card=(
            self.client_credit_card
            if hasattr(self, "client_credit_card")
            else None
        )
        _client_indexes=(
            self.client_indexes
            if hasattr(self, "client_indexes")
            else None
        )
        _client_relationships=(
            self.client_relationships
            if hasattr(self, "client_relationships")
            else None
        )
        _first_appointment_date=(
            self.first_appointment_date
            if hasattr(self, "first_appointment_date")
            else None
        )
        _first_class_date=(
            self.first_class_date
            if hasattr(self, "first_class_date")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_company=(
            self.is_company
            if hasattr(self, "is_company")
            else None
        )
        _is_prospect=(
            self.is_prospect
            if hasattr(self, "is_prospect")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _liability=(
            self.liability
            if hasattr(self, "liability")
            else None
        )
        _liability_release=(
            self.liability_release
            if hasattr(self, "liability_release")
            else None
        )
        _membership_icon=(
            self.membership_icon
            if hasattr(self, "membership_icon")
            else None
        )
        _mobile_provider=(
            self.mobile_provider
            if hasattr(self, "mobile_provider")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _red_alert=(
            self.red_alert
            if hasattr(self, "red_alert")
            else None
        )
        _yellow_alert=(
            self.yellow_alert
            if hasattr(self, "yellow_alert")
            else None
        )
        _middle_name=(
            self.middle_name
            if hasattr(self, "middle_name")
            else None
        )
        _prospect_stage=(
            self.prospect_stage
            if hasattr(self, "prospect_stage")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _account_balance=(
            self.account_balance
            if hasattr(self, "account_balance")
            else None
        )
        _address_line_1=(
            self.address_line_1
            if hasattr(self, "address_line_1")
            else None
        )
        _address_line_2=(
            self.address_line_2
            if hasattr(self, "address_line_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _work_extension=(
            self.work_extension
            if hasattr(self, "work_extension")
            else None
        )
        _referred_by=(
            self.referred_by
            if hasattr(self, "referred_by")
            else None
        )
        _photo_url=(
            self.photo_url
            if hasattr(self, "photo_url")
            else None
        )
        _emergency_contact_info_name=(
            self.emergency_contact_info_name
            if hasattr(self, "emergency_contact_info_name")
            else None
        )
        _emergency_contact_info_email=(
            self.emergency_contact_info_email
            if hasattr(self, "emergency_contact_info_email")
            else None
        )
        _emergency_contact_info_phone=(
            self.emergency_contact_info_phone
            if hasattr(self, "emergency_contact_info_phone")
            else None
        )
        _emergency_contact_info_relationship=(
            self.emergency_contact_info_relationship
            if hasattr(self, "emergency_contact_info_relationship")
            else None
        )
        _gender=(
            self.gender
            if hasattr(self, "gender")
            else None
        )
        _last_formula_notes=(
            self.last_formula_notes
            if hasattr(self, "last_formula_notes")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _sales_reps=(
            self.sales_reps
            if hasattr(self, "sales_reps")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _send_account_emails=(
            self.send_account_emails
            if hasattr(self, "send_account_emails")
            else None
        )
        _send_account_texts=(
            self.send_account_texts
            if hasattr(self, "send_account_texts")
            else None
        )
        _send_promotional_emails=(
            self.send_promotional_emails
            if hasattr(self, "send_promotional_emails")
            else None
        )
        _send_promotional_texts=(
            self.send_promotional_texts
            if hasattr(self, "send_promotional_texts")
            else None
        )
        _send_schedule_emails=(
            self.send_schedule_emails
            if hasattr(self, "send_schedule_emails")
            else None
        )
        _send_schedule_texts=(
            self.send_schedule_texts
            if hasattr(self, "send_schedule_texts")
            else None
        )
        _home_location=(
            self.home_location
            if hasattr(self, "home_location")
            else None
        )
        _locker_number=(
            self.locker_number
            if hasattr(self, "locker_number")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"suspension_info={_suspension_info!s}, "
            f"appointment_gender_preference={_appointment_gender_preference!s}, "
            f"birth_date={_birth_date!s}, "
            f"country={_country!s}, "
            f"creation_date={_creation_date!s}, "
            f"custom_client_fields={_custom_client_fields!s}, "
            f"client_credit_card={_client_credit_card!s}, "
            f"client_indexes={_client_indexes!s}, "
            f"client_relationships={_client_relationships!s}, "
            f"first_appointment_date={_first_appointment_date!s}, "
            f"first_class_date={_first_class_date!s}, "
            f"first_name={_first_name!s}, "
            f"id={_id!s}, "
            f"is_company={_is_company!s}, "
            f"is_prospect={_is_prospect!s}, "
            f"last_name={_last_name!s}, "
            f"liability={_liability!s}, "
            f"liability_release={_liability_release!s}, "
            f"membership_icon={_membership_icon!s}, "
            f"mobile_provider={_mobile_provider!s}, "
            f"notes={_notes!s}, "
            f"state={_state!s}, "
            f"unique_id={_unique_id!s}, "
            f"last_modified_date_time={_last_modified_date_time!s}, "
            f"red_alert={_red_alert!s}, "
            f"yellow_alert={_yellow_alert!s}, "
            f"middle_name={_middle_name!s}, "
            f"prospect_stage={_prospect_stage!s}, "
            f"email={_email!s}, "
            f"mobile_phone={_mobile_phone!s}, "
            f"home_phone={_home_phone!s}, "
            f"work_phone={_work_phone!s}, "
            f"account_balance={_account_balance!s}, "
            f"address_line_1={_address_line_1!s}, "
            f"address_line_2={_address_line_2!s}, "
            f"city={_city!s}, "
            f"postal_code={_postal_code!s}, "
            f"work_extension={_work_extension!s}, "
            f"referred_by={_referred_by!s}, "
            f"photo_url={_photo_url!s}, "
            f"emergency_contact_info_name={_emergency_contact_info_name!s}, "
            f"emergency_contact_info_email={_emergency_contact_info_email!s}, "
            f"emergency_contact_info_phone={_emergency_contact_info_phone!s}, "
            f"emergency_contact_info_relationship={_emergency_contact_info_relationship!s}, "
            f"gender={_gender!s}, "
            f"last_formula_notes={_last_formula_notes!s}, "
            f"active={_active!s}, "
            f"sales_reps={_sales_reps!s}, "
            f"status={_status!s}, "
            f"action={_action!s}, "
            f"send_account_emails={_send_account_emails!s}, "
            f"send_account_texts={_send_account_texts!s}, "
            f"send_promotional_emails={_send_promotional_emails!s}, "
            f"send_promotional_texts={_send_promotional_texts!s}, "
            f"send_schedule_emails={_send_schedule_emails!s}, "
            f"send_schedule_texts={_send_schedule_texts!s}, "
            f"home_location={_home_location!s}, "
            f"locker_number={_locker_number!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class CheckoutAlternativePaymentInfo(object):
    """Implementation of the 'CheckoutAlternativePaymentInfo' model.

    Request object to capture Alternative Payment information.

    Attributes:
        payment_method_id (int): The type of alternative payment. Possible values
            are:  * 997 - Indicates that this payment item is iDEAL.  * 801 -
            Indicates that this payment item is Apple Pay.
        amount (float): The amount to be paid

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_method_id": "PaymentMethodId",
        "amount": "Amount",
    }

    def __init__(
        self,
        payment_method_id=None,
        amount=None):
        """Initialize a CheckoutAlternativePaymentInfo instance."""
        # Initialize members of the class
        self.payment_method_id = payment_method_id
        self.amount = amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_method_id =\
            dictionary.get("PaymentMethodId")\
            if dictionary.get("PaymentMethodId")\
                else None
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else None

        # Return an object of this model
        return cls(payment_method_id,
                   amount)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _payment_method_id=self.payment_method_id
        _amount=self.amount
        return (
            f"{self.__class__.__name__}("
            f"payment_method_id={_payment_method_id!r}, "
            f"amount={_amount!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _payment_method_id=self.payment_method_id
        _amount=self.amount
        return (
            f"{self.__class__.__name__}("
            f"payment_method_id={_payment_method_id!s}, "
            f"amount={_amount!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddClientToClassVisit(object):
    """Implementation of the 'AddClientToClassVisit' model.

    Attributes:
        appointment_id (int): The appointment’s ID.
        appointment_gender_preference (AppointmentGenderPreference1Enum): The gender
            of staff member with whom the client prefers to book appointments.
        appointment_status (AppointmentStatusEnum): The status of the appointment.
        class_id (int): The class ID that was used to retrieve the visits.
        client_id (str): The ID of the client associated with the visit.
        start_date_time (datetime): The time this class is scheduled to start.
        end_date_time (datetime): The date and time the visit ends. The Public API
            returns UTC dates and times. For example, a class that occurs on June
            25th, 2018 at 2:15PM (EST) appears as “2018-06-25T19:15:00Z” because EST
            is five hours behind UTC. Date time pairs always return in the format
            YYYY-MM-DDTHH:mm:ssZ.
        id (int): The ID of the visit.
        last_modified_date_time (datetime): When included in the request, only
            records modified on or after the specified `LastModifiedDate` are
            included in the response. The Public API returns UTC dates and times. For
            example, a class that occurs on June 25th, 2018 at 2:15PM (EST) appears
            as “2018-06-25T19:15:00Z” because EST is five hours behind UTC. Date time
            pairs always return in the format YYYY-MM-DDTHH:mm:ssZ.
        late_cancelled (bool): When `true`, indicates that the class has been
            `LateCancelled`.<br />  When `false`, indicates that the class has not
            been `LateCancelled`.
        location_id (int): The ID of the location where the visit took place or is to
            take place.
        make_up (bool): When `true`, the client can make up this session and a
            session is not deducted from the pricing option that was used to sign the
            client into the enrollment. When the client has the make-up session, a
            session is automatically removed from a pricing option that matches the
            service category of the enrollment and is within the same date range of
            the missed session.<br />  When `false`, the client cannot make up this
            session. See [Enrollments:
            Make-ups](https://support.mindbodyonline.com/s/article/203259433-Enrollmen
            ts-Make-ups?language=en_US) for more information.
        name (str): The name of the class.
        service_id (int): The ID of the client's pricing option applied to the class
            visit.
        service_name (str): The name of the pricing option applied to the class visit.
        product_id (int): The business' ID of the type of pricing option used to pay
            for the class visit.
        signed_in (bool): When `true`, indicates that the client has been signed
            in.<br />  When `false`, indicates that the client has not been signed in.
        staff_id (int): The ID of the staff member who is teaching the class.
        web_signup (bool): When `true`, indicates that the client signed up
            online.<br />  When `false`, indicates that the client was signed up by a
            staff member.
        action (Action1Enum): The action taken.
        cross_regional_booking_performed (bool): When `true`, indicates that the
            client is paying for the visit using a pricing option from one of their
            associated cross-regional profiles.
        site_id (int): The ID of the business from which cross-regional payment is
            applied.
        waitlist_entry_id (int): When this value is not null, it indicates that the
            client is on the waiting list for the requested class. The only
            additional fields that are populated when this is not null are:  *
            ClassId  * ClientId    You can call GET WaitlistEntries using
            `WaitlistEntryId` to obtain more data about this waiting list entry.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "appointment_id": "AppointmentId",
        "appointment_gender_preference": "AppointmentGenderPreference",
        "appointment_status": "AppointmentStatus",
        "class_id": "ClassId",
        "client_id": "ClientId",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "id": "Id",
        "last_modified_date_time": "LastModifiedDateTime",
        "late_cancelled": "LateCancelled",
        "location_id": "LocationId",
        "make_up": "MakeUp",
        "name": "Name",
        "service_id": "ServiceId",
        "service_name": "ServiceName",
        "product_id": "ProductId",
        "signed_in": "SignedIn",
        "staff_id": "StaffId",
        "web_signup": "WebSignup",
        "action": "Action",
        "cross_regional_booking_performed": "CrossRegionalBookingPerformed",
        "site_id": "SiteId",
        "waitlist_entry_id": "WaitlistEntryId",
    }

    _optionals = [
        "appointment_id",
        "appointment_gender_preference",
        "appointment_status",
        "class_id",
        "client_id",
        "start_date_time",
        "end_date_time",
        "id",
        "last_modified_date_time",
        "late_cancelled",
        "location_id",
        "make_up",
        "name",
        "service_id",
        "service_name",
        "product_id",
        "signed_in",
        "staff_id",
        "web_signup",
        "action",
        "cross_regional_booking_performed",
        "site_id",
        "waitlist_entry_id",
    ]

    def __init__(
        self,
        appointment_id=APIHelper.SKIP,
        appointment_gender_preference=APIHelper.SKIP,
        appointment_status=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        id=APIHelper.SKIP,
        last_modified_date_time=APIHelper.SKIP,
        late_cancelled=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        make_up=APIHelper.SKIP,
        name=APIHelper.SKIP,
        service_id=APIHelper.SKIP,
        service_name=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        signed_in=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        web_signup=APIHelper.SKIP,
        action=APIHelper.SKIP,
        cross_regional_booking_performed=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        waitlist_entry_id=APIHelper.SKIP):
        """Initialize a AddClientToClassVisit instance."""
        # Initialize members of the class
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        if appointment_gender_preference is not APIHelper.SKIP:
            self.appointment_gender_preference = appointment_gender_preference
        if appointment_status is not APIHelper.SKIP:
            self.appointment_status = appointment_status
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if id is not APIHelper.SKIP:
            self.id = id
        if last_modified_date_time is not APIHelper.SKIP:
            self.last_modified_date_time =\
                 APIHelper.apply_datetime_converter(
                last_modified_date_time, APIHelper.RFC3339DateTime)\
                 if last_modified_date_time else None
        if late_cancelled is not APIHelper.SKIP:
            self.late_cancelled = late_cancelled
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if make_up is not APIHelper.SKIP:
            self.make_up = make_up
        if name is not APIHelper.SKIP:
            self.name = name
        if service_id is not APIHelper.SKIP:
            self.service_id = service_id
        if service_name is not APIHelper.SKIP:
            self.service_name = service_name
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if signed_in is not APIHelper.SKIP:
            self.signed_in = signed_in
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if web_signup is not APIHelper.SKIP:
            self.web_signup = web_signup
        if action is not APIHelper.SKIP:
            self.action = action
        if cross_regional_booking_performed is not APIHelper.SKIP:
            self.cross_regional_booking_performed = cross_regional_booking_performed
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if waitlist_entry_id is not APIHelper.SKIP:
            self.waitlist_entry_id = waitlist_entry_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP
        appointment_gender_preference =\
            dictionary.get("AppointmentGenderPreference")\
            if dictionary.get("AppointmentGenderPreference")\
                else APIHelper.SKIP
        appointment_status =\
            dictionary.get("AppointmentStatus")\
            if dictionary.get("AppointmentStatus")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        last_modified_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDateTime")).datetime\
            if dictionary.get("LastModifiedDateTime") else APIHelper.SKIP
        late_cancelled =\
            dictionary.get("LateCancelled")\
            if "LateCancelled" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        make_up =\
            dictionary.get("MakeUp")\
            if "MakeUp" in dictionary.keys()\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        service_id =\
            dictionary.get("ServiceId")\
            if dictionary.get("ServiceId")\
                else APIHelper.SKIP
        service_name =\
            dictionary.get("ServiceName")\
            if dictionary.get("ServiceName")\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        signed_in =\
            dictionary.get("SignedIn")\
            if "SignedIn" in dictionary.keys()\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        web_signup =\
            dictionary.get("WebSignup")\
            if "WebSignup" in dictionary.keys()\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        cross_regional_booking_performed =\
            dictionary.get("CrossRegionalBookingPerformed")\
            if "CrossRegionalBookingPerformed" in dictionary.keys()\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        waitlist_entry_id =\
            dictionary.get("WaitlistEntryId")\
            if dictionary.get("WaitlistEntryId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(appointment_id,
                   appointment_gender_preference,
                   appointment_status,
                   class_id,
                   client_id,
                   start_date_time,
                   end_date_time,
                   id,
                   last_modified_date_time,
                   late_cancelled,
                   location_id,
                   make_up,
                   name,
                   service_id,
                   service_name,
                   product_id,
                   signed_in,
                   staff_id,
                   web_signup,
                   action,
                   cross_regional_booking_performed,
                   site_id,
                   waitlist_entry_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _appointment_status=(
            self.appointment_status
            if hasattr(self, "appointment_status")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _late_cancelled=(
            self.late_cancelled
            if hasattr(self, "late_cancelled")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _make_up=(
            self.make_up
            if hasattr(self, "make_up")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _service_id=(
            self.service_id
            if hasattr(self, "service_id")
            else None
        )
        _service_name=(
            self.service_name
            if hasattr(self, "service_name")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _web_signup=(
            self.web_signup
            if hasattr(self, "web_signup")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _cross_regional_booking_performed=(
            self.cross_regional_booking_performed
            if hasattr(self, "cross_regional_booking_performed")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!r}, "
            f"appointment_gender_preference={_appointment_gender_preference!r}, "
            f"appointment_status={_appointment_status!r}, "
            f"class_id={_class_id!r}, "
            f"client_id={_client_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"id={_id!r}, "
            f"last_modified_date_time={_last_modified_date_time!r}, "
            f"late_cancelled={_late_cancelled!r}, "
            f"location_id={_location_id!r}, "
            f"make_up={_make_up!r}, "
            f"name={_name!r}, "
            f"service_id={_service_id!r}, "
            f"service_name={_service_name!r}, "
            f"product_id={_product_id!r}, "
            f"signed_in={_signed_in!r}, "
            f"staff_id={_staff_id!r}, "
            f"web_signup={_web_signup!r}, "
            f"action={_action!r}, "
            f"cross_regional_booking_performed={_cross_regional_booking_performed!r}, "
            f"site_id={_site_id!r}, "
            f"waitlist_entry_id={_waitlist_entry_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _appointment_status=(
            self.appointment_status
            if hasattr(self, "appointment_status")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _late_cancelled=(
            self.late_cancelled
            if hasattr(self, "late_cancelled")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _make_up=(
            self.make_up
            if hasattr(self, "make_up")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _service_id=(
            self.service_id
            if hasattr(self, "service_id")
            else None
        )
        _service_name=(
            self.service_name
            if hasattr(self, "service_name")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _web_signup=(
            self.web_signup
            if hasattr(self, "web_signup")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _cross_regional_booking_performed=(
            self.cross_regional_booking_performed
            if hasattr(self, "cross_regional_booking_performed")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!s}, "
            f"appointment_gender_preference={_appointment_gender_preference!s}, "
            f"appointment_status={_appointment_status!s}, "
            f"class_id={_class_id!s}, "
            f"client_id={_client_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"id={_id!s}, "
            f"last_modified_date_time={_last_modified_date_time!s}, "
            f"late_cancelled={_late_cancelled!s}, "
            f"location_id={_location_id!s}, "
            f"make_up={_make_up!s}, "
            f"name={_name!s}, "
            f"service_id={_service_id!s}, "
            f"service_name={_service_name!s}, "
            f"product_id={_product_id!s}, "
            f"signed_in={_signed_in!s}, "
            f"staff_id={_staff_id!s}, "
            f"web_signup={_web_signup!s}, "
            f"action={_action!s}, "
            f"cross_regional_booking_performed={_cross_regional_booking_performed!s}, "
            f"site_id={_site_id!s}, "
            f"waitlist_entry_id={_waitlist_entry_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddArrivalRequest(object):
    """Implementation of the 'AddArrivalRequest' model.

    Attributes:
        client_id (str): The ID of the requested client.
        location_id (int): The ID of the location for the requested arrival.
        arrival_type_id (int): The ID of the arrival program (service category) under
            which this arrival is to be logged. If this is not provided, the program
            ID of the first arrival pricing option found will be used.  OPTIONAL:
            will take first payment found if not provided  Default: **null**
        lead_channel_id (int): The ID of the Lead Channel ID from lead management. If
            this is supplied then it will map lead channel on the lead management.
            If this is not supplied then it wont save anything.  This parameters
            required to track the lead channel if new client added while adding
            arrival of client on non home location.
        test (bool): When `true`, indicates that the arrival log is to be validated,
            but no new arrival data is added. When `false`, the arrival is logged and
            the database is affected.  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "location_id": "LocationId",
        "arrival_type_id": "ArrivalTypeId",
        "lead_channel_id": "LeadChannelId",
        "test": "Test",
    }

    _optionals = [
        "arrival_type_id",
        "lead_channel_id",
        "test",
    ]

    def __init__(
        self,
        client_id=None,
        location_id=None,
        arrival_type_id=APIHelper.SKIP,
        lead_channel_id=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a AddArrivalRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.location_id = location_id
        if arrival_type_id is not APIHelper.SKIP:
            self.arrival_type_id = arrival_type_id
        if lead_channel_id is not APIHelper.SKIP:
            self.lead_channel_id = lead_channel_id
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else None
        arrival_type_id =\
            dictionary.get("ArrivalTypeId")\
            if dictionary.get("ArrivalTypeId")\
                else APIHelper.SKIP
        lead_channel_id =\
            dictionary.get("LeadChannelId")\
            if dictionary.get("LeadChannelId")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   location_id,
                   arrival_type_id,
                   lead_channel_id,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _location_id=self.location_id
        _arrival_type_id=(
            self.arrival_type_id
            if hasattr(self, "arrival_type_id")
            else None
        )
        _lead_channel_id=(
            self.lead_channel_id
            if hasattr(self, "lead_channel_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"location_id={_location_id!r}, "
            f"arrival_type_id={_arrival_type_id!r}, "
            f"lead_channel_id={_lead_channel_id!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _location_id=self.location_id
        _arrival_type_id=(
            self.arrival_type_id
            if hasattr(self, "arrival_type_id")
            else None
        )
        _lead_channel_id=(
            self.lead_channel_id
            if hasattr(self, "lead_channel_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"location_id={_location_id!s}, "
            f"arrival_type_id={_arrival_type_id!s}, "
            f"lead_channel_id={_lead_channel_id!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class StaffSessionType(object):
    """Implementation of the 'StaffSessionType' model.

    Attributes:
        staff_id (int): The staff member Id
        mtype (Type2Enum): Contains the class description session type.
        id (int): This session type’s unique Id.
        name (str): The name of this session type.
        num_deducted (int): The number of sessions that this session type deducts
            from the pricing option used to pay for this type of session.
        program_id (int): This session type’s service category Id.
        category (str): This session type’s category.
        category_id (int): This session type’s category Id.
        subcategory (str): This session type’s subcategory.
        subcategory_id (int): This session type’s subcategory Id.
        time_length (int): The model property of type int.
        prep_time (int): Prep time in minutes
        finish_time (int): Finish time in minutes
        pay_rate_type (str): The pay rate type
        pay_rate_amount (float): The pay rate amount

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "mtype": "Type",
        "id": "Id",
        "name": "Name",
        "num_deducted": "NumDeducted",
        "program_id": "ProgramId",
        "category": "Category",
        "category_id": "CategoryId",
        "subcategory": "Subcategory",
        "subcategory_id": "SubcategoryId",
        "time_length": "TimeLength",
        "prep_time": "PrepTime",
        "finish_time": "FinishTime",
        "pay_rate_type": "PayRateType",
        "pay_rate_amount": "PayRateAmount",
    }

    _optionals = [
        "staff_id",
        "mtype",
        "id",
        "name",
        "num_deducted",
        "program_id",
        "category",
        "category_id",
        "subcategory",
        "subcategory_id",
        "time_length",
        "prep_time",
        "finish_time",
        "pay_rate_type",
        "pay_rate_amount",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        mtype=APIHelper.SKIP,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        num_deducted=APIHelper.SKIP,
        program_id=APIHelper.SKIP,
        category=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        subcategory=APIHelper.SKIP,
        subcategory_id=APIHelper.SKIP,
        time_length=APIHelper.SKIP,
        prep_time=APIHelper.SKIP,
        finish_time=APIHelper.SKIP,
        pay_rate_type=APIHelper.SKIP,
        pay_rate_amount=APIHelper.SKIP):
        """Initialize a StaffSessionType instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if num_deducted is not APIHelper.SKIP:
            self.num_deducted = num_deducted
        if program_id is not APIHelper.SKIP:
            self.program_id = program_id
        if category is not APIHelper.SKIP:
            self.category = category
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if subcategory is not APIHelper.SKIP:
            self.subcategory = subcategory
        if subcategory_id is not APIHelper.SKIP:
            self.subcategory_id = subcategory_id
        if time_length is not APIHelper.SKIP:
            self.time_length = time_length
        if prep_time is not APIHelper.SKIP:
            self.prep_time = prep_time
        if finish_time is not APIHelper.SKIP:
            self.finish_time = finish_time
        if pay_rate_type is not APIHelper.SKIP:
            self.pay_rate_type = pay_rate_type
        if pay_rate_amount is not APIHelper.SKIP:
            self.pay_rate_amount = pay_rate_amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        num_deducted =\
            dictionary.get("NumDeducted")\
            if dictionary.get("NumDeducted")\
                else APIHelper.SKIP
        program_id =\
            dictionary.get("ProgramId")\
            if dictionary.get("ProgramId")\
                else APIHelper.SKIP
        category =\
            dictionary.get("Category")\
            if dictionary.get("Category")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        subcategory =\
            dictionary.get("Subcategory")\
            if dictionary.get("Subcategory")\
                else APIHelper.SKIP
        subcategory_id =\
            dictionary.get("SubcategoryId")\
            if dictionary.get("SubcategoryId")\
                else APIHelper.SKIP
        time_length =\
            dictionary.get("TimeLength")\
            if dictionary.get("TimeLength")\
                else APIHelper.SKIP
        prep_time =\
            dictionary.get("PrepTime")\
            if dictionary.get("PrepTime")\
                else APIHelper.SKIP
        finish_time =\
            dictionary.get("FinishTime")\
            if dictionary.get("FinishTime")\
                else APIHelper.SKIP
        pay_rate_type =\
            dictionary.get("PayRateType")\
            if dictionary.get("PayRateType")\
                else APIHelper.SKIP
        pay_rate_amount =\
            dictionary.get("PayRateAmount")\
            if dictionary.get("PayRateAmount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   mtype,
                   id,
                   name,
                   num_deducted,
                   program_id,
                   category,
                   category_id,
                   subcategory,
                   subcategory_id,
                   time_length,
                   prep_time,
                   finish_time,
                   pay_rate_type,
                   pay_rate_amount)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"mtype={_mtype!r}, "
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"num_deducted={_num_deducted!r}, "
            f"program_id={_program_id!r}, "
            f"category={_category!r}, "
            f"category_id={_category_id!r}, "
            f"subcategory={_subcategory!r}, "
            f"subcategory_id={_subcategory_id!r}, "
            f"time_length={_time_length!r}, "
            f"prep_time={_prep_time!r}, "
            f"finish_time={_finish_time!r}, "
            f"pay_rate_type={_pay_rate_type!r}, "
            f"pay_rate_amount={_pay_rate_amount!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"mtype={_mtype!s}, "
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"num_deducted={_num_deducted!s}, "
            f"program_id={_program_id!s}, "
            f"category={_category!s}, "
            f"category_id={_category_id!s}, "
            f"subcategory={_subcategory!s}, "
            f"subcategory_id={_subcategory_id!s}, "
            f"time_length={_time_length!s}, "
            f"prep_time={_prep_time!s}, "
            f"finish_time={_finish_time!s}, "
            f"pay_rate_type={_pay_rate_type!s}, "
            f"pay_rate_amount={_pay_rate_amount!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class PaymentProcessingFailure(object):
    """Implementation of the 'PaymentProcessingFailure' model.

    Contains information about any payment processing failure.  Specifically for when
    an SCA challenge is

    Attributes:
        mtype (str): Returned only if SCA challenge is indicated.
        message (str): Returned only if SCA challenge is indicated.
        authentication_redirect_url (str): Returned only if SCA challenge is
            indicated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype": "Type",
        "message": "Message",
        "authentication_redirect_url": "AuthenticationRedirectUrl",
    }

    _optionals = [
        "mtype",
        "message",
        "authentication_redirect_url",
    ]

    def __init__(
        self,
        mtype=APIHelper.SKIP,
        message=APIHelper.SKIP,
        authentication_redirect_url=APIHelper.SKIP):
        """Initialize a PaymentProcessingFailure instance."""
        # Initialize members of the class
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if message is not APIHelper.SKIP:
            self.message = message
        if authentication_redirect_url is not APIHelper.SKIP:
            self.authentication_redirect_url = authentication_redirect_url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        message =\
            dictionary.get("Message")\
            if dictionary.get("Message")\
                else APIHelper.SKIP
        authentication_redirect_url =\
            dictionary.get("AuthenticationRedirectUrl")\
            if dictionary.get("AuthenticationRedirectUrl")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(mtype,
                   message,
                   authentication_redirect_url)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        _authentication_redirect_url=(
            self.authentication_redirect_url
            if hasattr(self, "authentication_redirect_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!r}, "
            f"message={_message!r}, "
            f"authentication_redirect_url={_authentication_redirect_url!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        _authentication_redirect_url=(
            self.authentication_redirect_url
            if hasattr(self, "authentication_redirect_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!s}, "
            f"message={_message!s}, "
            f"authentication_redirect_url={_authentication_redirect_url!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class StaffSetting(object):
    """Implementation of the 'StaffSetting' model.

    contains the information about the staff settings.

    Attributes:
        use_staff_nicknames (bool): When `true`, `DisplayName` of the staff will be
            displayed.  When `false`, `DisplayName` will be displayed as null.
        show_staff_last_names_on_schedules (bool): When `true`, indicates that the
            Name contains both the `FirstName` and `LastName` of the staff.  When
            `false`, indicates that the Name contains only the `FirstName` of the
            staff.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "use_staff_nicknames": "UseStaffNicknames",
        "show_staff_last_names_on_schedules": "ShowStaffLastNamesOnSchedules",
    }

    _optionals = [
        "use_staff_nicknames",
        "show_staff_last_names_on_schedules",
    ]

    def __init__(
        self,
        use_staff_nicknames=APIHelper.SKIP,
        show_staff_last_names_on_schedules=APIHelper.SKIP):
        """Initialize a StaffSetting instance."""
        # Initialize members of the class
        if use_staff_nicknames is not APIHelper.SKIP:
            self.use_staff_nicknames = use_staff_nicknames
        if show_staff_last_names_on_schedules is not APIHelper.SKIP:
            self.show_staff_last_names_on_schedules =\
                 show_staff_last_names_on_schedules

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        use_staff_nicknames =\
            dictionary.get("UseStaffNicknames")\
            if "UseStaffNicknames" in dictionary.keys()\
                else APIHelper.SKIP
        show_staff_last_names_on_schedules =\
            dictionary.get("ShowStaffLastNamesOnSchedules")\
            if "ShowStaffLastNamesOnSchedules" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(use_staff_nicknames,
                   show_staff_last_names_on_schedules)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _use_staff_nicknames=(
            self.use_staff_nicknames
            if hasattr(self, "use_staff_nicknames")
            else None
        )
        _show_staff_last_names_on_schedules=(
            self.show_staff_last_names_on_schedules
            if hasattr(self, "show_staff_last_names_on_schedules")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"use_staff_nicknames={_use_staff_nicknames!r}, "
            f"show_staff_last_names_on_schedules={_show_staff_last_names_on_schedules!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _use_staff_nicknames=(
            self.use_staff_nicknames
            if hasattr(self, "use_staff_nicknames")
            else None
        )
        _show_staff_last_names_on_schedules=(
            self.show_staff_last_names_on_schedules
            if hasattr(self, "show_staff_last_names_on_schedules")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"use_staff_nicknames={_use_staff_nicknames!s}, "
            f"show_staff_last_names_on_schedules={_show_staff_last_names_on_schedules!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class DeactivatePromoCodeRequest(object):
    """Implementation of the 'DeactivatePromoCodeRequest' model.

    Attributes:
        promotion_id (int): The promocodeID

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "promotion_id": "PromotionId",
    }

    def __init__(
        self,
        promotion_id=None):
        """Initialize a DeactivatePromoCodeRequest instance."""
        # Initialize members of the class
        self.promotion_id = promotion_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        promotion_id =\
            dictionary.get("PromotionId")\
            if dictionary.get("PromotionId")\
                else None

        # Return an object of this model
        return cls(promotion_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _promotion_id=self.promotion_id
        return (
            f"{self.__class__.__name__}("
            f"promotion_id={_promotion_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _promotion_id=self.promotion_id
        return (
            f"{self.__class__.__name__}("
            f"promotion_id={_promotion_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetPackagesRequest(object):
    """Implementation of the 'GetPackagesRequest' model.

    Attributes:
        package_ids (List[int]): A list of the packages IDs to filter by.
        sell_online (bool): When `true`, only returns products that can be sold
            online.<br />  When `false`, all products are returned.<br />  Default:
            **false**
        location_id (int): The location ID to use to determine the tax for the
            products that this request returns.<br />  Default: **online store**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "package_ids": "PackageIds",
        "sell_online": "SellOnline",
        "location_id": "LocationId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "package_ids",
        "sell_online",
        "location_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        package_ids=APIHelper.SKIP,
        sell_online=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetPackagesRequest instance."""
        # Initialize members of the class
        if package_ids is not APIHelper.SKIP:
            self.package_ids = package_ids
        if sell_online is not APIHelper.SKIP:
            self.sell_online = sell_online
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        package_ids =\
            dictionary.get("PackageIds")\
            if dictionary.get("PackageIds")\
                else APIHelper.SKIP
        sell_online =\
            dictionary.get("SellOnline")\
            if "SellOnline" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(package_ids,
                   sell_online,
                   location_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _package_ids=(
            self.package_ids
            if hasattr(self, "package_ids")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"package_ids={_package_ids!r}, "
            f"sell_online={_sell_online!r}, "
            f"location_id={_location_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _package_ids=(
            self.package_ids
            if hasattr(self, "package_ids")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"package_ids={_package_ids!s}, "
            f"sell_online={_sell_online!s}, "
            f"location_id={_location_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class SendPasswordResetEmailRequest(object):
    """Implementation of the 'SendPasswordResetEmailRequest' model.

    Request to send a password reset email to a user

    Attributes:
        user_email (str): The user’s email address. The software uses this parameter
            as the username.
        user_first_name (str): The user’s first name. The software uses this
            parameter to verify the user.
        user_last_name (str): The user’s last name. The software uses this parameter
            to verify the user.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_email": "UserEmail",
        "user_first_name": "UserFirstName",
        "user_last_name": "UserLastName",
    }

    def __init__(
        self,
        user_email=None,
        user_first_name=None,
        user_last_name=None):
        """Initialize a SendPasswordResetEmailRequest instance."""
        # Initialize members of the class
        self.user_email = user_email
        self.user_first_name = user_first_name
        self.user_last_name = user_last_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        user_email =\
            dictionary.get("UserEmail")\
            if dictionary.get("UserEmail")\
                else None
        user_first_name =\
            dictionary.get("UserFirstName")\
            if dictionary.get("UserFirstName")\
                else None
        user_last_name =\
            dictionary.get("UserLastName")\
            if dictionary.get("UserLastName")\
                else None

        # Return an object of this model
        return cls(user_email,
                   user_first_name,
                   user_last_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _user_email=self.user_email
        _user_first_name=self.user_first_name
        _user_last_name=self.user_last_name
        return (
            f"{self.__class__.__name__}("
            f"user_email={_user_email!r}, "
            f"user_first_name={_user_first_name!r}, "
            f"user_last_name={_user_last_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _user_email=self.user_email
        _user_first_name=self.user_first_name
        _user_last_name=self.user_last_name
        return (
            f"{self.__class__.__name__}("
            f"user_email={_user_email!s}, "
            f"user_first_name={_user_first_name!s}, "
            f"user_last_name={_user_last_name!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.checkout_item_wrapper import (
    CheckoutItemWrapper,
)
from mindbodypublicapi.models.checkout_payment_info import (
    CheckoutPaymentInfo,
)


class CheckoutShoppingCartRequest(object):
    """Implementation of the 'CheckoutShoppingCartRequest' model.

    Attributes:
        cart_id (str): The unique ID of the shopping cart to be processed. You can
            use this value to maintain a persistent cart. If you do not specify a
            cart ID, the MINDBODY software generates one.
        client_id (str): The RSSID of the client making the purchase. A 'ClientId' OR
            'UniqueClientId' must be specified to complete a sale.
        unique_client_id (int): The UniqueId of the client making the purchase. A
            'ClientId' OR 'UniqueClientId' must be specified to complete a sale.
            Note: you need to provide the 'UniqueClientId' OR the 'ClientId'. If both
            are provided, the 'UniqueClientId' takes precedence.
        payer_client_id (str): The RSSID of the client paying for the purchase. This
            client needs to have a relationship of type "Pays for" with the client
            specified in the 'ClientId' or 'UniqueClientId' fields.
        unique_payer_client_id (int): The UniqueId of the client paying for the
            purchase. This client needs to have a relationship of type "Pays for"
            with the client specified in the 'ClientId' or 'UniqueClientId' field.
            Note: you need to provide the 'UniquePayerClientId' OR the
            'PayerClientId'. If both are provided, the 'UniquePayerClientId' takes
            precedence.
        test (bool): When `true`, indicates that the contents of the cart are
            validated, but the transaction does not take place. You should use this
            parameter during testing and when checking the calculated totals of the
            items in the cart.<br />  When `false`, the transaction takes place and
            the database is affected.<br />  Default: **false**
        items (List[CheckoutItemWrapper]): A list of the items in the cart.
        in_store (bool): When `true`, indicates that the cart is to be completed by a
            staff member and is to take place at one of the business’ physical
            locations.<br />  When `false`, indicates that the cart is to be
            completed by a client from the business’ online store.<br />  Default:
            **false**
        calculate_tax (bool): When `true`, indicates that the tax should be
            calculated.  When `false`, indicates that the tax should not be
            calculated.  Default: **true**
        promotion_code (str): Promotion code to be applied to the cart.
        payments (List[CheckoutPaymentInfo]): A list of payment information objects
            to be applied to payment against the items in the cart.
        send_email (bool): When `true`, sends a purchase receipt email to the client.
            Note that all appropriate permissions and settings must be enabled for
            the client to receive an email.<br />  Default: **false**
        location_id (int): The location ID to be used for pulling business mode
            prices and taxes. If no location ID is supplied, it defaults to the
            online store, represented by a null value.   Default: **null** (the
            online store)
        image (str): The byte array data of the signature image.
        image_file_name (str): The name of the signature image being uploaded.
        consumer_present (bool): When `true`, indicates that the consumer is present
            or otherwise able to successfully negotiate an SCA challenge. It is not a
            good idea to have this always be `false` as that could very likely lead
            to a bank declining all transactions for the merchant.   Defaults to
            `false`.
        payment_authentication_callback_url (str): The URL consumer is redirected to
            if the bank requests SCA. This field is only needed if ConsumerPresent is
            `true`
        transaction_ids (List[int]): The list of TransactionIds provided with initial
            response containing SCA Challenge URLs for ConsumerPresent transactions
        is_billing_postal_code_required (bool): the flag to check billing post code
            is required or not.
        enforce_location_restrictions (bool): When `true`, enforces "sell at"
            location restrictions on the cart items.  When `false`, "sell at"
            location restrictions are not enforced.  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "items": "Items",
        "payments": "Payments",
        "cart_id": "CartId",
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "payer_client_id": "PayerClientId",
        "unique_payer_client_id": "UniquePayerClientId",
        "test": "Test",
        "in_store": "InStore",
        "calculate_tax": "CalculateTax",
        "promotion_code": "PromotionCode",
        "send_email": "SendEmail",
        "location_id": "LocationId",
        "image": "Image",
        "image_file_name": "ImageFileName",
        "consumer_present": "ConsumerPresent",
        "payment_authentication_callback_url": "PaymentAuthenticationCallbackUrl",
        "transaction_ids": "TransactionIds",
        "is_billing_postal_code_required": "IsBillingPostalCodeRequired",
        "enforce_location_restrictions": "EnforceLocationRestrictions",
    }

    _optionals = [
        "cart_id",
        "client_id",
        "unique_client_id",
        "payer_client_id",
        "unique_payer_client_id",
        "test",
        "in_store",
        "calculate_tax",
        "promotion_code",
        "send_email",
        "location_id",
        "image",
        "image_file_name",
        "consumer_present",
        "payment_authentication_callback_url",
        "transaction_ids",
        "is_billing_postal_code_required",
        "enforce_location_restrictions",
    ]

    def __init__(
        self,
        items=None,
        payments=None,
        cart_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        payer_client_id=APIHelper.SKIP,
        unique_payer_client_id=APIHelper.SKIP,
        test=APIHelper.SKIP,
        in_store=APIHelper.SKIP,
        calculate_tax=APIHelper.SKIP,
        promotion_code=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        image=APIHelper.SKIP,
        image_file_name=APIHelper.SKIP,
        consumer_present=APIHelper.SKIP,
        payment_authentication_callback_url=APIHelper.SKIP,
        transaction_ids=APIHelper.SKIP,
        is_billing_postal_code_required=APIHelper.SKIP,
        enforce_location_restrictions=APIHelper.SKIP):
        """Initialize a CheckoutShoppingCartRequest instance."""
        # Initialize members of the class
        if cart_id is not APIHelper.SKIP:
            self.cart_id = cart_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if payer_client_id is not APIHelper.SKIP:
            self.payer_client_id = payer_client_id
        if unique_payer_client_id is not APIHelper.SKIP:
            self.unique_payer_client_id = unique_payer_client_id
        if test is not APIHelper.SKIP:
            self.test = test
        self.items = items
        if in_store is not APIHelper.SKIP:
            self.in_store = in_store
        if calculate_tax is not APIHelper.SKIP:
            self.calculate_tax = calculate_tax
        if promotion_code is not APIHelper.SKIP:
            self.promotion_code = promotion_code
        self.payments = payments
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if image is not APIHelper.SKIP:
            self.image = image
        if image_file_name is not APIHelper.SKIP:
            self.image_file_name = image_file_name
        if consumer_present is not APIHelper.SKIP:
            self.consumer_present = consumer_present
        if payment_authentication_callback_url is not APIHelper.SKIP:
            self.payment_authentication_callback_url =\
                 payment_authentication_callback_url
        if transaction_ids is not APIHelper.SKIP:
            self.transaction_ids = transaction_ids
        if is_billing_postal_code_required is not APIHelper.SKIP:
            self.is_billing_postal_code_required = is_billing_postal_code_required
        if enforce_location_restrictions is not APIHelper.SKIP:
            self.enforce_location_restrictions = enforce_location_restrictions

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        items = None
        if dictionary.get("Items") is not None:
            items = [
                CheckoutItemWrapper.from_dictionary(x)
                    for x in dictionary.get("Items")
            ]
        payments = None
        if dictionary.get("Payments") is not None:
            payments = [
                CheckoutPaymentInfo.from_dictionary(x)
                    for x in dictionary.get("Payments")
            ]
        cart_id =\
            dictionary.get("CartId")\
            if dictionary.get("CartId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        payer_client_id =\
            dictionary.get("PayerClientId")\
            if dictionary.get("PayerClientId")\
                else APIHelper.SKIP
        unique_payer_client_id =\
            dictionary.get("UniquePayerClientId")\
            if dictionary.get("UniquePayerClientId")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        in_store =\
            dictionary.get("InStore")\
            if "InStore" in dictionary.keys()\
                else APIHelper.SKIP
        calculate_tax =\
            dictionary.get("CalculateTax")\
            if "CalculateTax" in dictionary.keys()\
                else APIHelper.SKIP
        promotion_code =\
            dictionary.get("PromotionCode")\
            if dictionary.get("PromotionCode")\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        image =\
            dictionary.get("Image")\
            if dictionary.get("Image")\
                else APIHelper.SKIP
        image_file_name =\
            dictionary.get("ImageFileName")\
            if dictionary.get("ImageFileName")\
                else APIHelper.SKIP
        consumer_present =\
            dictionary.get("ConsumerPresent")\
            if "ConsumerPresent" in dictionary.keys()\
                else APIHelper.SKIP
        payment_authentication_callback_url =\
            dictionary.get("PaymentAuthenticationCallbackUrl")\
            if dictionary.get("PaymentAuthenticationCallbackUrl")\
                else APIHelper.SKIP
        transaction_ids =\
            dictionary.get("TransactionIds")\
            if dictionary.get("TransactionIds")\
                else APIHelper.SKIP
        is_billing_postal_code_required =\
            dictionary.get("IsBillingPostalCodeRequired")\
            if "IsBillingPostalCodeRequired" in dictionary.keys()\
                else APIHelper.SKIP
        enforce_location_restrictions =\
            dictionary.get("EnforceLocationRestrictions")\
            if "EnforceLocationRestrictions" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(items,
                   payments,
                   cart_id,
                   client_id,
                   unique_client_id,
                   payer_client_id,
                   unique_payer_client_id,
                   test,
                   in_store,
                   calculate_tax,
                   promotion_code,
                   send_email,
                   location_id,
                   image,
                   image_file_name,
                   consumer_present,
                   payment_authentication_callback_url,
                   transaction_ids,
                   is_billing_postal_code_required,
                   enforce_location_restrictions)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _cart_id=(
            self.cart_id
            if hasattr(self, "cart_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _payer_client_id=(
            self.payer_client_id
            if hasattr(self, "payer_client_id")
            else None
        )
        _unique_payer_client_id=(
            self.unique_payer_client_id
            if hasattr(self, "unique_payer_client_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _items=self.items
        _in_store=(
            self.in_store
            if hasattr(self, "in_store")
            else None
        )
        _calculate_tax=(
            self.calculate_tax
            if hasattr(self, "calculate_tax")
            else None
        )
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _payments=self.payments
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _image=(
            self.image
            if hasattr(self, "image")
            else None
        )
        _image_file_name=(
            self.image_file_name
            if hasattr(self, "image_file_name")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _transaction_ids=(
            self.transaction_ids
            if hasattr(self, "transaction_ids")
            else None
        )
        _is_billing_postal_code_required=(
            self.is_billing_postal_code_required
            if hasattr(self, "is_billing_postal_code_required")
            else None
        )
        _enforce_location_restrictions=(
            self.enforce_location_restrictions
            if hasattr(self, "enforce_location_restrictions")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"cart_id={_cart_id!r}, "
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"payer_client_id={_payer_client_id!r}, "
            f"unique_payer_client_id={_unique_payer_client_id!r}, "
            f"test={_test!r}, "
            f"items={_items!r}, "
            f"in_store={_in_store!r}, "
            f"calculate_tax={_calculate_tax!r}, "
            f"promotion_code={_promotion_code!r}, "
            f"payments={_payments!r}, "
            f"send_email={_send_email!r}, "
            f"location_id={_location_id!r}, "
            f"image={_image!r}, "
            f"image_file_name={_image_file_name!r}, "
            f"consumer_present={_consumer_present!r}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!r}, "
            f"transaction_ids={_transaction_ids!r}, "
            f"is_billing_postal_code_required={_is_billing_postal_code_required!r}, "
            f"enforce_location_restrictions={_enforce_location_restrictions!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _cart_id=(
            self.cart_id
            if hasattr(self, "cart_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _payer_client_id=(
            self.payer_client_id
            if hasattr(self, "payer_client_id")
            else None
        )
        _unique_payer_client_id=(
            self.unique_payer_client_id
            if hasattr(self, "unique_payer_client_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _items=self.items
        _in_store=(
            self.in_store
            if hasattr(self, "in_store")
            else None
        )
        _calculate_tax=(
            self.calculate_tax
            if hasattr(self, "calculate_tax")
            else None
        )
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _payments=self.payments
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _image=(
            self.image
            if hasattr(self, "image")
            else None
        )
        _image_file_name=(
            self.image_file_name
            if hasattr(self, "image_file_name")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _transaction_ids=(
            self.transaction_ids
            if hasattr(self, "transaction_ids")
            else None
        )
        _is_billing_postal_code_required=(
            self.is_billing_postal_code_required
            if hasattr(self, "is_billing_postal_code_required")
            else None
        )
        _enforce_location_restrictions=(
            self.enforce_location_restrictions
            if hasattr(self, "enforce_location_restrictions")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"cart_id={_cart_id!s}, "
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"payer_client_id={_payer_client_id!s}, "
            f"unique_payer_client_id={_unique_payer_client_id!s}, "
            f"test={_test!s}, "
            f"items={_items!s}, "
            f"in_store={_in_store!s}, "
            f"calculate_tax={_calculate_tax!s}, "
            f"promotion_code={_promotion_code!s}, "
            f"payments={_payments!s}, "
            f"send_email={_send_email!s}, "
            f"location_id={_location_id!s}, "
            f"image={_image!s}, "
            f"image_file_name={_image_file_name!s}, "
            f"consumer_present={_consumer_present!s}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!s}, "
            f"transaction_ids={_transaction_ids!s}, "
            f"is_billing_postal_code_required={_is_billing_postal_code_required!s}, "
            f"enforce_location_restrictions={_enforce_location_restrictions!s}, "
            f")"
        )



# ruff: noqa: D104 | Missing docstring in public package
# ruff: noqa: RUF022 | `__all__` is not sorted
__all__ = [
    "action_1_enum",
    "action_10_enum",
    "action_8_enum",
    "action_enum",
    "add_appointment_add_on_request",
    "add_appointment_add_on_response",
    "add_appointment_outcome",
    "add_appointment_request",
    "add_appointment_response",
    "add_arrival_request",
    "add_arrival_response",
    "add_availabilities_request",
    "add_availabilities_response",
    "add_class_enrollment_schedule_request",
    "add_client_direct_debit_info_request",
    "add_client_direct_debit_info_response",
    "add_client_request",
    "add_client_response",
    "add_client_to_class_request",
    "add_client_to_class_response",
    "add_client_to_class_visit",
    "add_client_to_enrollment_request",
    "add_contact_log_request",
    "add_contact_log_type",
    "add_formula_note_request",
    "add_multiple_appointments_request",
    "add_multiple_appointments_response",
    "add_on_small",
    "add_on_small_1",
    "add_promo_code_request",
    "add_promo_code_response",
    "add_site_client_index_request",
    "add_site_client_index_response",
    "add_staff_availability_request",
    "add_staff_request",
    "add_staff_response",
    "allowed_permission_enum",
    "alternative_payment_method",
    "amenity",
    "amenity_1",
    "api_error",
    "api_error_1",
    "applicable_item",
    "appointment",
    "appointment_1",
    "appointment_add_on",
    "appointment_gender_preference_1_enum",
    "appointment_gender_preference_enum",
    "appointment_option",
    "appointment_staff",
    "appointment_status_enum",
    "assign_staff_session_type_request",
    "assign_staff_session_type_response",
    "assigned_client_index",
    "autopay_schedule",
    "autopay_status_enum",
    "availability",
    "availability_1",
    "booking_status_enum",
    "booking_window",
    "cancel_single_class_request",
    "cancel_single_class_response",
    "cart_item",
    "category",
    "checkout_alternative_payment_info",
    "checkout_appointment_booking_request",
    "checkout_item",
    "checkout_item_wrapper",
    "checkout_payment_info",
    "checkout_shopping_cart_request",
    "checkout_shopping_cart_response",
    "class_client_detail",
    "class_description",
    "class_schedule",
    "client",
    "client_arrival",
    "client_contract",
    "client_credit_card",
    "client_document",
    "client_duplicate",
    "client_index",
    "client_index_value",
    "client_membership",
    "client_memberships",
    "client_purchase_record",
    "client_relationship",
    "client_reward_transaction",
    "client_service",
    "client_suspension_info",
    "client_with_suspension_info",
    "color",
    "commission_detail",
    "commission_payroll_purchase_event",
    "complete_checkout_shopping_cart_using_alternative_payments_request",
    "contact_log",
    "contact_log_comment",
    "contact_log_sub_type",
    "contact_log_type",
    "content_format_enum",
    "contract",
    "contract_item",
    "copy_credit_card_request",
    "copy_credit_card_response",
    "copy_credit_card_response_client",
    "course",
    "create_reservation_response",
    "credit_card_info",
    "cross_regional_client_association",
    "custom_client_field",
    "custom_client_field_value",
    "custom_payment_method",
    "days_of_week_enum",
    "days_valid_enum",
    "deactivate_promo_code_request",
    "delete_availability_request",
    "delete_client_formula_note_request",
    "delete_contact_log_request",
    "denied_permission_enum",
    "direct_debit_info",
    "discount",
    "formula_note_response",
    "frequency_type_enum",
    "gender_option",
    "gender_preference_enum",
    "get_activation_code_response",
    "get_active_client_memberships_request",
    "get_active_client_memberships_response",
    "get_active_clients_memberships_request",
    "get_active_clients_memberships_response",
    "get_active_session_times_request",
    "get_active_session_times_response",
    "get_add_ons_request",
    "get_add_ons_response",
    "get_alternative_payment_methods_request",
    "get_alternative_payment_methods_response",
    "get_appointment_options_response",
    "get_available_dates_request",
    "get_available_dates_response",
    "get_bookable_items_request",
    "get_bookable_items_response",
    "get_categories_request",
    "get_categories_response",
    "get_class_descriptions_request",
    "get_class_descriptions_response",
    "get_class_schedules_request",
    "get_class_schedules_response",
    "get_class_visits_request",
    "get_class_visits_response",
    "get_classes_request",
    "get_classes_response",
    "get_client_account_balances_request",
    "get_client_account_balances_response",
    "get_client_complete_info_request",
    "get_client_complete_info_response",
    "get_client_contracts_request",
    "get_client_contracts_response",
    "get_client_duplicates_request",
    "get_client_duplicates_response",
    "get_client_formula_notes_request",
    "get_client_formula_notes_response",
    "get_client_indexes_request",
    "get_client_indexes_response",
    "get_client_purchases_request",
    "get_client_purchases_response",
    "get_client_referral_types_request",
    "get_client_referral_types_response",
    "get_client_rewards_request",
    "get_client_rewards_response",
    "get_client_schedule_request",
    "get_client_schedule_response",
    "get_client_services_request",
    "get_client_services_response",
    "get_client_visits_request",
    "get_client_visits_response",
    "get_clients_request",
    "get_clients_response",
    "get_commissions_request",
    "get_commissions_response",
    "get_contact_log_types_request",
    "get_contact_log_types_response",
    "get_contact_logs_request",
    "get_contact_logs_response",
    "get_contracts_request",
    "get_contracts_response",
    "get_courses_reponse",
    "get_courses_request",
    "get_cross_regional_client_associations_request",
    "get_cross_regional_client_associations_response",
    "get_custom_client_fields_request",
    "get_custom_client_fields_response",
    "get_custom_payment_methods_request",
    "get_custom_payment_methods_response",
    "get_enrollments_request",
    "get_enrollments_response",
    "get_genders_response",
    "get_gift_card_balance_response",
    "get_gift_card_response",
    "get_gift_cards_request",
    "get_liability_waiver_response",
    "get_locations_request",
    "get_locations_response",
    "get_memberships_request",
    "get_memberships_response",
    "get_mobile_providers_request",
    "get_mobile_providers_response",
    "get_packages_request",
    "get_packages_response",
    "get_payment_types_request",
    "get_payment_types_response",
    "get_pick_a_spot_class_response",
    "get_products_inventory_request",
    "get_products_inventory_response",
    "get_products_request",
    "get_products_response",
    "get_programs_request",
    "get_programs_response",
    "get_promo_codes_request",
    "get_promo_codes_response",
    "get_prospect_stages_request",
    "get_prospect_stages_response",
    "get_relationships_request",
    "get_relationships_response",
    "get_required_client_fields_response",
    "get_reservation_response",
    "get_resource_availabilities_request",
    "get_resources_request",
    "get_resources_response",
    "get_sales_reps_request",
    "get_sales_reps_response",
    "get_sales_request",
    "get_sales_response",
    "get_schedule_items_request",
    "get_schedule_items_response",
    "get_scheduled_service_earnings_request",
    "get_scheduled_service_earnings_response",
    "get_semesters_request",
    "get_semesters_response",
    "get_services_request",
    "get_services_response",
    "get_session_types_request",
    "get_session_types_response",
    "get_sites_request",
    "get_sites_response",
    "get_staff_appointments_request",
    "get_staff_appointments_response",
    "get_staff_image_url_request",
    "get_staff_image_url_response",
    "get_staff_permissions_request",
    "get_staff_permissions_response",
    "get_staff_request",
    "get_staff_response",
    "get_staff_session_types_request",
    "get_staff_session_types_response",
    "get_time_cards_request",
    "get_time_cards_response",
    "get_tips_request",
    "get_tips_response",
    "get_transactions_request",
    "get_transactions_response",
    "get_unavailabilities_request",
    "get_unavailabilities_response",
    "get_waitlist_entries_request",
    "get_waitlist_entries_response",
    "gift_card",
    "gift_card_layout",
    "http_content",
    "initiate_checkout_shopping_cart_using_alternative_payments_request",
    "initiate_purchase_contract_request",
    "issue_request",
    "issue_response",
    "lead_channel",
    "level",
    "liability",
    "location",
    "location_1",
    "m_0_culture_neutral_public_key_token_b_77_a_5_c_561934_e_089",
    "mclass",
    "membership",
    "membership_type_restriction",
    "merge_clients_request",
    "minimum_commitment_unit_enum",
    "mobile_provider",
    "package",
    "pagination",
    "pagination_response",
    "payment_method_enum",
    "payment_processing_failure",
    "payment_type",
    "pick_a_spot_class",
    "pricing_relationships",
    "product",
    "products_inventory",
    "program",
    "program_1",
    "program_membership",
    "promo_code",
    "prospect_stage",
    "public_display_1_enum",
    "public_display_enum",
    "purchase_account_credit_request",
    "purchase_account_credit_response",
    "purchase_contract_request",
    "purchase_contract_response",
    "purchase_contract_response_totals",
    "purchase_gift_card_request",
    "purchase_gift_card_response",
    "purchased_item",
    "relationship",
    "remove_client_from_class_request",
    "remove_client_from_class_response",
    "remove_clients_from_classes_request",
    "remove_clients_from_classes_response",
    "remove_from_waitlist_request",
    "request_schedule_type_enum",
    "reservation",
    "resource",
    "resource_1",
    "resource_availability",
    "resource_availability_1",
    "resource_slim",
    "response_details",
    "return_sale_request",
    "return_sale_response",
    "sale",
    "sale_payment",
    "sales_rep",
    "sales_rep_response",
    "schedule_type_1_enum",
    "schedule_type_2_enum",
    "schedule_type_3_enum",
    "schedule_type_4_enum",
    "schedule_type_enum",
    "scheduled_service_earnings_event",
    "scheduled_service_type_enum",
    "semester",
    "send_auto_email_request",
    "send_password_reset_email_request",
    "service",
    "service_tag",
    "session_type",
    "session_type_1",
    "shopping_cart",
    "site",
    "size",
    "spot",
    "staff",
    "staff_1",
    "staff_permission_group",
    "staff_session_type",
    "staff_setting",
    "status_1_enum",
    "status_enum",
    "stored_card_info",
    "sub_category",
    "substitute_class_teacher_request",
    "substitute_class_teacher_response",
    "substitute_teacher_class",
    "suspend_contract_request",
    "suspend_contract_response",
    "terminate_contract_request",
    "terminate_contract_response",
    "time_card_event",
    "tip",
    "transaction",
    "transaction_response",
    "type_1_enum",
    "type_2_enum",
    "type_enum",
    "unavailability",
    "unavailability_1",
    "unavailability_plain",
    "upcoming_autopay_event",
    "update_appointment_request",
    "update_appointment_response",
    "update_availability_request",
    "update_availability_response",
    "update_class_enrollment_schedule_request",
    "update_class_schedule_notes_request",
    "update_client_contract_autopays_request",
    "update_client_request",
    "update_client_response",
    "update_client_rewards_request",
    "update_client_service_request",
    "update_client_service_response",
    "update_client_visit_request",
    "update_client_visit_response",
    "update_contact_log_comment",
    "update_contact_log_request",
    "update_contact_log_type",
    "update_pricing_option_request",
    "update_product_price_request",
    "update_product_price_response",
    "update_product_request",
    "update_reservation_response",
    "update_sale_date_request",
    "update_sale_date_response",
    "update_service_request",
    "update_service_response",
    "update_site_client_index_request",
    "update_site_client_index_response",
    "update_staff_permissions_request",
    "update_staff_permissions_response",
    "update_staff_request",
    "update_staff_response",
    "upload_client_document_request",
    "upload_client_document_response",
    "upload_client_photo_request",
    "upload_client_photo_response",
    "user",
    "visit",
    "visit_waitlist_info",
    "visit_with_waitlist_info",
    "waitlist_entry",
    "written_class_schedules_info",
]



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.pagination_response import (
    PaginationResponse,
)
from mindbodypublicapi.models.scheduled_service_earnings_event import (
    ScheduledServiceEarningsEvent,
)


class GetScheduledServiceEarningsResponse(object):
    """Implementation of the 'GetScheduledServiceEarningsResponse' model.

    Attributes:
        pagination_response (PaginationResponse): Contains information about the
            pagination to use.
        scheduled_service_earnings (List[ScheduledServiceEarningsEvent]): Contains
            the class payroll events.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "pagination_response": "PaginationResponse",
        "scheduled_service_earnings": "ScheduledServiceEarnings",
    }

    _optionals = [
        "pagination_response",
        "scheduled_service_earnings",
    ]

    def __init__(
        self,
        pagination_response=APIHelper.SKIP,
        scheduled_service_earnings=APIHelper.SKIP):
        """Initialize a GetScheduledServiceEarningsResponse instance."""
        # Initialize members of the class
        if pagination_response is not APIHelper.SKIP:
            self.pagination_response = pagination_response
        if scheduled_service_earnings is not APIHelper.SKIP:
            self.scheduled_service_earnings = scheduled_service_earnings

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        pagination_response =\
            PaginationResponse.from_dictionary(
                dictionary.get("PaginationResponse"))\
                if "PaginationResponse" in dictionary.keys()\
                else APIHelper.SKIP
        scheduled_service_earnings = None
        if dictionary.get("ScheduledServiceEarnings") is not None:
            scheduled_service_earnings = [
                ScheduledServiceEarningsEvent.from_dictionary(x)
                    for x in dictionary.get("ScheduledServiceEarnings")
            ]
        else:
            scheduled_service_earnings = APIHelper.SKIP

        # Return an object of this model
        return cls(pagination_response,
                   scheduled_service_earnings)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _scheduled_service_earnings=(
            self.scheduled_service_earnings
            if hasattr(self, "scheduled_service_earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!r}, "
            f"scheduled_service_earnings={_scheduled_service_earnings!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _scheduled_service_earnings=(
            self.scheduled_service_earnings
            if hasattr(self, "scheduled_service_earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!s}, "
            f"scheduled_service_earnings={_scheduled_service_earnings!s}, "
            f")"
        )
